==> ToolChain_STM32_1.0.42.tar.bz: ToolChain_STM32_1.0.42/ToolChain/install_20_ExampleLEDs.sh <==
#!/bin/bash

#
#  Install script for Fixpoint Mathematical Library 
#  URL: http://code.google.com/p/fixpointlib/
#
#  Script written by Gregor Rebel 2010-2011.
# 
#  Feel free do distribute and change to your own needs!
#
# Tested successfully on:
# Ubuntu 10.04 Netbook Edition x86
# KUbuntu 11.04 x86
# openSuSE 11.4 x86
# XUbuntu 11.10 x64

source scripts/installFuncs.sh

if [ "$USER" == "root" ]; then
  echo "$0: ERROR this script should not been run as user root!"
  exit 10
fi

INSTALLPATH="600_example_leds"
dir "$INSTALLPATH"
cd "$INSTALLPATH"

#{ IMPLEMENT YOUR INSTALL SCRIPT BELOW -----------------------------------------------

  createExtensionMakefileHead ${INSTALLPATH} #{
  cat <<END_OF_MAKEFILE >>../extensions/makefile.$INSTALLPATH #{
# Adds Libraries/stm32_Registers.* to the project
# Provides global variables with detailed structures for various CortexM3 registers.
# See Libraries/stm32_Registers.* for details.

# activate certain parts of source-code
COMPILE_OPTS += -DEXTENSION_$INSTALLPATH

ifndef uCONTROLLER
  STM32F10X_HD  =1
  uCONTROLLER   =STM32F10X_HD 
endif

INCLUDE_DIRS += -I additionals/examples/
vpath %.c additionals/examples/

MAIN_OBJS += example_leds.o

END_OF_MAKEFILE
#}
  createExtensionMakefileTail ${INSTALLPATH} #}
  File="../extensions/activate.${INSTALLPATH}.sh" #{
  createActivateScriptHead $File $0 "Example code for a multitasking Heartbeat LED" 
  cat <<END_OF_ACTIVATE >>$File #{

activate.250_stm_std_peripherals__rcc.sh QUIET
activate.500_ttc_gpio.sh QUIET

# rm 2>/dev/null \$Dir_ExtensionsActive/makefile.600_example_*
createLink \$Dir_Extensions/makefile.$INSTALLPATH \$Dir_ExtensionsActive/makefile.$INSTALLPATH '' QUIET

END_OF_ACTIVATE
#}
  createActivateScriptTail $File $INSTALLPATH
  #}

  echo "Installed successfully: $INSTALLPATH"

cd ..
#} IMPLEMENT YOUR INSTALL SCRIPT ABOVE -----------------------------------------------

exit 0

==> ToolChain_STM32_1.0.45.tar.bz: ToolChain_STM32_1.0.45/ToolChain/install_20_ExampleLEDs.sh <==
#!/bin/bash

#
#  Install script for Fixpoint Mathematical Library 
#  URL: http://code.google.com/p/fixpointlib/
#
#  Script written by Gregor Rebel 2010-2011.
# 
#  Feel free do distribute and change to your own needs!
#
# Tested successfully on:
# Ubuntu 10.04 Netbook Edition x86
# KUbuntu 11.04 x86
# openSuSE 11.4 x86
# XUbuntu 11.10 x64

source scripts/installFuncs.sh

if [ "$USER" == "root" ]; then
  echo "$0: ERROR this script should not been run as user root!"
  exit 10
fi

INSTALLPATH="600_example_leds"
dir "$INSTALLPATH"
cd "$INSTALLPATH"

#{ IMPLEMENT YOUR INSTALL SCRIPT BELOW -----------------------------------------------

  createExtensionMakefileHead ${INSTALLPATH} #{
  cat <<END_OF_MAKEFILE >>../extensions/makefile.$INSTALLPATH #{
# Adds Libraries/stm32_Registers.* to the project
# Provides global variables with detailed structures for various CortexM3 registers.
# See Libraries/stm32_Registers.* for details.

# activate certain parts of source-code
COMPILE_OPTS += -DEXTENSION_$INSTALLPATH

MAIN_OBJS += example_leds.o

END_OF_MAKEFILE
#}
  createExtensionMakefileTail ${INSTALLPATH} #}
  File="../extensions/activate.${INSTALLPATH}.sh" #{
  createActivateScriptHead $File $0 "Example code for a multitasking Heartbeat LED" 
  cat <<END_OF_ACTIVATE >>$File #{

#activate.250_stm_std_peripherals__rcc.sh QUIET \"\$0\"
activate.500_ttc_gpio.sh QUIET \"\$0\"

# rm 2>/dev/null \$Dir_ExtensionsActive/makefile.600_example_*
createLink \$Dir_Extensions/makefile.$INSTALLPATH \$Dir_ExtensionsActive/makefile.$INSTALLPATH '' QUIET

END_OF_ACTIVATE
#}
  createActivateScriptTail $File $INSTALLPATH
  #}

  echo "Installed successfully: $INSTALLPATH"

cd ..
#} IMPLEMENT YOUR INSTALL SCRIPT ABOVE -----------------------------------------------

exit 0
